/**********************************************************
***********************************************************
*				European Southern Observatory
*		     VLTI MIDI Data Reduction Software
*
* Module name:	iauExchange.h
* Description:	Definitions of data structures, function prototypes for IAU exchange
*
*
* History:		
* 10-Jul-03		(csabet) Created. Derived from John Young <jsy1001@cam.ac.uk>
***********************************************************
**********************************************************/
#ifndef _IAU_EXCHANGE_H
#define _IAU_EXCHANGE_H

/******************************************************************************
*	Compiler directives
******************************************************************************/

/**********************************************************
*	Include files
**********************************************************/

/**********************************************************
*	Constant definitions
**********************************************************/

/**********************************************************
*	Global Variables 
**********************************************************/

/**********************************************************
*	Type definitions 
**********************************************************/
typedef struct _element	// Array element crresponds to one row of an OI_ARRAY FITS table
{
	char	*tel_name;
	char 	*sta_name;
	int 	sta_index;
	float 	diameter;
	double 	*staxyz;	//	Array of 3
} Element;

typedef struct _oi_array 
{
	char	*revision;
	char 	*arrname;
	char 	*frame;
	double 	arrayx, arrayy, arrayz;
	int 	nelement;
	Element	*elem;
} OiArray;

typedef struct _target	// Array target crresponds to one row of an OI_TARGET FITS table
{
	int 	target_id;
	char 	*target;
	double 	raep0;
	double	decep0;
	float 	equinox;
	double 	ra_err;
	double	dec_err;
	double 	sysvel;
	char 	*veltyp;
	char	*veldef;
	double 	pmra;
	double	pmdec;
	double 	pmra_err;
	double	pmdec_err;
	float 	parallax;
	float	para_err;
	char 	*spectyp;
} Target;

typedef struct _oi_target 
{
	char 	*revision;
	int 	ntarget;
	Target 	*targ;
} OiTarget;

typedef struct _oi_wavelength 
{
	char	*revision;
	char 	*insname;
	int 	nwave;
	float 	*eff_wave;
	float 	*eff_band;
} OiWavelength;


typedef struct _oi_vis_record	// Complex visibility record corresponds to one row of an OI_VIS FITS table */
{
	int 	target_id;
	double 	time;
	double	mjd;
	double 	int_time;
	double 	*visamp;
	double	*visamperr;
	double 	*visphi;
	double	*visphierr;
	double 	ucoord;
	double	vcoord;
	int 	*sta_index;	// Array of 2
	char 	*flag;
} OiVisRecord;

typedef struct _oi_vis 
{
	char 			*revision;
	char 			*date_obs;
	char 			*arrname;	/*	Empty string means "not specified" */
	char 			*insname;
	long 			numrec;
	int 			nwave;
	OiVisRecord		*record;
} OiVis;


typedef struct _oi_vis2_record	/*	Visibility squared record corresponds to one row of an OI_VIS2 FITS table. */
{
	int 	target_id;
	double 	time;
	double 	mjd;
	double 	int_time;
	double 	*vis2data;
	double	*vis2err;
	double 	ucoord;
	double	vcoord;
	int 	*sta_index;	// Array of 2
	char 	*flag;
} OiVis2Record;

typedef struct _oi_vis2 
{
	char 			*revision;
	char 			*date_obs;
	char 			*arrname;	// Empty string means "not specified"
	char 			*insname;
	long 			numrec;
	int				nwave;
	OiVis2Record	*record;
} OiVis2;

typedef struct _oi_t3_record	// Triple product record corresponds to one row of an OI_T3 FITS table
{
	int 	target_id;
	double 	time;
	double 	mjd;
	double 	int_time;
	double 	*t3amp;
	double	*t3amperr;
	double 	*t3phi;
	double	*t3phierr;
	double 	u1coord;
	double	v1coord;
	double	u2coord;
	double	v2coord;
	int		*sta_index;	// Array of 3
	char	*flag;
} OiT3Record;

typedef struct _oi_t3 
{
	char 		*revision;
	char 		*date_obs;
	char 		*arrname;	// Empty string means "not specified"
	char 		*insname;
	long 		numrec;
	int 		nwave;
	OiT3Record	*record;
} OiT3;


/**********************************************************
*	Function Prototypes
**********************************************************/

/*********************************************************/
#endif
/*********************************************************/
